pub struct ShareBalanceContext<T>(pub PhantomData<T>);Expand description
Plugin execution context for ShareBalanceFamily.
The generic T is expected to be a concrete implementation of
LazyBalance, defining the core types this context operates on.
Implements LazyBalanceContext, providing bounds, extension schemas,
and error typing required by the balance model.
Tuple Fields
0: PhantomData<T>Trait Implementations
Sourcetype Deposit = ModelDeposit
type Deposit = ModelDeposit
Sourcetype Withdraw = ModelWithdraw
type Withdraw = ModelWithdraw
Sourcetype Drain = ModelDrain
type Drain = ModelDrain
Sourcetype CanDeposit = ModelCanDeposit
type CanDeposit = ModelCanDeposit
Sourcetype CanMint = ModelCanMint
type CanMint = ModelCanMint
Sourcetype CanReap = ModelCanReap
type CanReap = ModelCanReap
Sourcetype CanWithdraw = ModelCanWithdraw
type CanWithdraw = ModelCanWithdraw
Sourcetype TotalValue = ModelTotalValue
type TotalValue = ModelTotalValue
Sourcetype ReceiptActiveValue = ModelReceiptActiveValue
type ReceiptActiveValue = ModelReceiptActiveValue
Sourcetype HasDeposits = ModelHasDeposits
type HasDeposits = ModelHasDeposits
Sourcetype ReceiptDepositValue = ModelReceiptDepositValue
type ReceiptDepositValue = ModelReceiptDepositValue
Sourcetype DepositLimits = ModelDepositLimits
type DepositLimits = ModelDepositLimits
Sourcetype MintLimits = ModelMintLimits
type MintLimits = ModelMintLimits
Sourcetype ReapLimits = ModelReapLimits
type ReapLimits = ModelReapLimits
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, _input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, _input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, _input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, _input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, _input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, _input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Sourcefn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
fn compute(&self, input: In, _context: &ShareBalanceContext<T>) -> Out
Allocates two asset fields:
effective(internally index0)issued(internally index1)
Allocates two asset fields:
checkpoint(internally index0)drainpoint(internally index1)
Allocates two asset fields:
principal(internally index0)shares(internally index1)
This binds the LazyBalanceError discriminant to ShareBalanceError,
allowing all LazyBalance plugin models with context ShareBalanceContext
to resolve their error type.
type Error = ShareBalanceError